---
title: Model Examples Pull No Model Uncertainty
---

![Model Examples Pull No Model Uncertainty](../baseline/model_examples_pull_no_model_unc.png)

??? imports "Imports"
    ```python
    --8<--
    examples/model_ex/model_examples_pull_no_model_unc.py:imports
    --8<--
    ```

??? setup "Setup"
    ```python
    --8<--
    examples/model_ex/model_examples_pull_no_model_unc.py:setup
    --8<--
    ```

!!! tip "Code"
    ```python
    --8<--
    examples/model_ex/model_examples_pull_no_model_unc.py:plot_body
    --8<--
    ```

??? code "Full code"
    ```python
    --8<--
    examples/model_ex/model_examples_pull_no_model_unc.py:full_code
    --8<--
    ```
